@@ -29,6 +29,9 @@ FAILEDOPERATION_ACCOUNTALREADYEXISTS = 'FailedOperation.AccountAlreadyExists'
 # 账号为当前用户
 FAILEDOPERATION_ACCOUNTISYOURSELF = 'FailedOperation.AccountIsYourSelf'
 
+# 自带许可镜像暂时不支持共享。
+FAILEDOPERATION_BYOLIMAGESHAREFAILED = 'FailedOperation.BYOLImageShareFailed'
+
 # 未找到指定的容灾组
 FAILEDOPERATION_DISASTERRECOVERGROUPNOTFOUND = 'FailedOperation.DisasterRecoverGroupNotFound'
 
@@ -203,6 +206,9 @@ INVALIDKEYPAIRNAMETOOLONG = 'InvalidKeyPairNameTooLong'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 最多指定一个参数。
+INVALIDPARAMETER_ATMOSTONE = 'InvalidParameter.AtMostOne'
+
 # DataDiskIds不应该传入RootDisk的Id。
 INVALIDPARAMETER_DATADISKIDCONTAINSROOTDISK = 'InvalidParameter.DataDiskIdContainsRootDisk'
 
@@ -278,6 +284,9 @@ INVALIDPARAMETERCONFLICT = 'InvalidParameterConflict'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 入参数目不相等。
+INVALIDPARAMETERVALUE_AMOUNTNOTEQUAL = 'InvalidParameterValue.AmountNotEqual'
+
 # 共享带宽包ID不合要求，请提供规范的共享带宽包ID，类似bwp-xxxxxxxx，字母x代表小写字符或者数字。
 INVALIDPARAMETERVALUE_BANDWIDTHPACKAGEIDMALFORMED = 'InvalidParameterValue.BandwidthPackageIdMalformed'
 
@@ -293,18 +302,27 @@ INVALIDPARAMETERVALUE_CAMROLENAMEMALFORMED = 'InvalidParameterValue.CamRoleNameM
 # 找不到对应的CHC物理服务器。
 INVALIDPARAMETERVALUE_CHCHOSTSNOTFOUND = 'InvalidParameterValue.ChcHostsNotFound'
 
+# 该CHC未配置任何网络。
+INVALIDPARAMETERVALUE_CHCNETWORKEMPTY = 'InvalidParameterValue.ChcNetworkEmpty'
+
 # SSD云硬盘为数据盘时，购买大小不得小于100GB
 INVALIDPARAMETERVALUE_CLOUDSSDDATADISKSIZETOOSMALL = 'InvalidParameterValue.CloudSsdDataDiskSizeTooSmall'
 
 # 核心计数不合法。
 INVALIDPARAMETERVALUE_CORECOUNTVALUE = 'InvalidParameterValue.CoreCountValue'
 
+# 已经存在部署VPC。
+INVALIDPARAMETERVALUE_DEPLOYVPCALREADYEXISTS = 'InvalidParameterValue.DeployVpcAlreadyExists'
+
 # 置放群组ID格式错误。
 INVALIDPARAMETERVALUE_DISASTERRECOVERGROUPIDMALFORMED = 'InvalidParameterValue.DisasterRecoverGroupIdMalformed'
 
 # 参数值重复。
 INVALIDPARAMETERVALUE_DUPLICATE = 'InvalidParameterValue.Duplicate'
 
+# 重复标签。
+INVALIDPARAMETERVALUE_DUPLICATETAGS = 'InvalidParameterValue.DuplicateTags'
+
 # 非GPU实例不允许转为GPU实例。
 INVALIDPARAMETERVALUE_GPUINSTANCEFAMILY = 'InvalidParameterValue.GPUInstanceFamily'
 
@@ -461,6 +479,9 @@ INVALIDPARAMETERVALUE_SUBNETNOTEXIST = 'InvalidParameterValue.SubnetNotExist'
 # 指定的标签不存在。
 INVALIDPARAMETERVALUE_TAGKEYNOTFOUND = 'InvalidParameterValue.TagKeyNotFound'
 
+# 标签配额超限。
+INVALIDPARAMETERVALUE_TAGQUOTALIMITEXCEEDED = 'InvalidParameterValue.TagQuotaLimitExceeded'
+
 # 每核心线程数不合法。
 INVALIDPARAMETERVALUE_THREADPERCOREVALUE = 'InvalidParameterValue.ThreadPerCoreValue'
 
@@ -566,6 +587,9 @@ LIMITEXCEEDED_SINGLEUSGQUOTA = 'LimitExceeded.SingleUSGQuota'
 # 竞价实例类型配额不足
 LIMITEXCEEDED_SPOTQUOTA = 'LimitExceeded.SpotQuota'
 
+# 标签绑定的资源数量已达到配额限制。
+LIMITEXCEEDED_TAGRESOURCEQUOTA = 'LimitExceeded.TagResourceQuota'
+
 # 退还失败，退还配额已达上限。
 LIMITEXCEEDED_USERRETURNQUOTA = 'LimitExceeded.UserReturnQuota'
 
@@ -593,6 +617,9 @@ MUTEXOPERATION_TASKRUNNING = 'MutexOperation.TaskRunning'
 # 不允许未配置部署网络的CHC安装云上镜像。
 OPERATIONDENIED_CHCINSTALLCLOUDIMAGEWITHOUTDEPLOYNETWORK = 'OperationDenied.ChcInstallCloudImageWithoutDeployNetwork'
 
+# 禁止管控账号操作。
+OPERATIONDENIED_INNERUSERPROHIBITACTION = 'OperationDenied.InnerUserProhibitAction'
+
 # 实例正在执行其他操作，请稍后再试。
 OPERATIONDENIED_INSTANCEOPERATIONINPROGRESS = 'OperationDenied.InstanceOperationInProgress'
 
@@ -629,6 +656,9 @@ RESOURCENOTFOUND_HPCCLUSTER = 'ResourceNotFound.HpcCluster'
 # 指定的置放群组不存在。
 RESOURCENOTFOUND_INVALIDPLACEMENTSET = 'ResourceNotFound.InvalidPlacementSet'
 
+# 可用区不支持此机型。
+RESOURCENOTFOUND_INVALIDZONEINSTANCETYPE = 'ResourceNotFound.InvalidZoneInstanceType'
+
 # 无可用的缺省类型的CBS资源。
 RESOURCENOTFOUND_NODEFAULTCBS = 'ResourceNotFound.NoDefaultCbs'
 
@@ -764,6 +794,9 @@ UNSUPPORTEDOPERATION_INVALIDDATADISK = 'UnsupportedOperation.InvalidDataDisk'
 # 不支持指定的磁盘
 UNSUPPORTEDOPERATION_INVALIDDISK = 'UnsupportedOperation.InvalidDisk'
 
+# 镜像许可类型与实例不符，请选择其他镜像。
+UNSUPPORTEDOPERATION_INVALIDIMAGELICENSETYPEFORRESET = 'UnsupportedOperation.InvalidImageLicenseTypeForReset'
+
 # 不支持已经设置了释放时间的实例，请在实例详情页撤销实例定时销毁后再试。
 UNSUPPORTEDOPERATION_INVALIDINSTANCENOTSUPPORTEDPROTECTEDINSTANCE = 'UnsupportedOperation.InvalidInstanceNotSupportedProtectedInstance'
 
@@ -827,6 +860,9 @@ UNSUPPORTEDOPERATION_SHAREDIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.Shared
 # 请求不支持特殊机型的实例
 UNSUPPORTEDOPERATION_SPECIALINSTANCETYPE = 'UnsupportedOperation.SpecialInstanceType'
 
+# 该地域不支持竞价实例。
+UNSUPPORTEDOPERATION_SPOTUNSUPPORTEDREGION = 'UnsupportedOperation.SpotUnsupportedRegion'
+
 # 不支持关机不收费特性
 UNSUPPORTEDOPERATION_STOPPEDMODESTOPCHARGING = 'UnsupportedOperation.StoppedModeStopCharging'
 
