@@ -56,9 +56,15 @@ FAILEDOPERATION_COMPONENTCLIENTUNPACK = 'FailedOperation.ComponentClientUnpack'
 # 请求(http请求)其他云服务失败。
 FAILEDOPERATION_COMPONENTCLINETHTTP = 'FailedOperation.ComponentClinetHttp'
 
+# 创建CLS采集配置失败。
+FAILEDOPERATION_CREATECLSCONFIG = 'FailedOperation.CreateClsConfig'
+
 # 创建CLS日志集失败。
 FAILEDOPERATION_CREATECLSLOGSET = 'FailedOperation.CreateClsLogSet'
 
+# 创建 CLS 主题失败。
+FAILEDOPERATION_CREATECLSTOPIC = 'FailedOperation.CreateClsTopic'
+
 # cvm创建节点报错。
 FAILEDOPERATION_CVMCOMMON = 'FailedOperation.CvmCommon'
 
@@ -83,6 +89,9 @@ FAILEDOPERATION_GETCLSLOGSET = 'FailedOperation.GetClsLogSet'
 # 获取CLS机器组失败。
 FAILEDOPERATION_GETCLSMACHINEGROUP = 'FailedOperation.GetClsMachineGroup'
 
+# 通过配置文件创建集群Client错误。
+FAILEDOPERATION_KUBECLIENTCONF = 'FailedOperation.KubeClientConf'
+
 # 连接用户Kubernetes集群失败。
 FAILEDOPERATION_KUBECLIENTCONNECTION = 'FailedOperation.KubeClientConnection'
 
@@ -98,12 +107,21 @@ FAILEDOPERATION_KUBERNETESCREATEOPERATIONERROR = 'FailedOperation.KubernetesCrea
 # Kubernetes Delete 操作错误。
 FAILEDOPERATION_KUBERNETESDELETEOPERATIONERROR = 'FailedOperation.KubernetesDeleteOperationError'
 
+# 获取Kubernetes资源失败。
+FAILEDOPERATION_KUBERNETESGETOPERATIONERROR = 'FailedOperation.KubernetesGetOperationError'
+
 # Kubernetes未知错误。
 FAILEDOPERATION_KUBERNETESINTERNAL = 'FailedOperation.KubernetesInternal'
 
+# Kubernetes patch 操作失败。
+FAILEDOPERATION_KUBERNETESPATCHOPERATIONERROR = 'FailedOperation.KubernetesPatchOperationError'
+
 # 底层调用CLB未知错误。
 FAILEDOPERATION_LBCOMMON = 'FailedOperation.LbCommon'
 
+# 修改CLS索引失败。
+FAILEDOPERATION_MODIFYCLSINDEX = 'FailedOperation.ModifyClsIndex'
+
 # 网络扩展错误。
 FAILEDOPERATION_NETWORKSCALEERROR = 'FailedOperation.NetworkScaleError'
 
@@ -419,6 +437,9 @@ OPERATIONDENIED_CLUSTERINDELETIONPROTECTION = 'OperationDenied.ClusterInDeletion
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
+# 资源已存在。
+RESOURCEINUSE_RESOURCEEXISTALREADY = 'ResourceInUse.ResourceExistAlready'
+
 # 资源不足。
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
